@@ -4,9 +4,11 @@
  *  for how to set the configuration options.
  */
 
-/* These hints thanks to Federico Spinazzi <spinazzi@databankgroup.it> */
+/* These hints thanks to Federico Spinazzi <spinazzi@databankgroup.it>
+   (2001) and yselkowitz@users.sourceforge.net (October 2005)
+*/
 
-#include <curses.h>
+#include <ncurses.h>
 
 #ifdef C_PANELSUPPORT
 #include <panel.h>
@@ -20,6 +22,8 @@
 #include <form.h>
 #endif
 
+#undef bool
+
 #undef  C_LONGNAME
 #undef  C_LONG0ARGS
 #undef  C_LONG2ARGS
